/*****************************************************************************
 *
 *  BoolParameter.h                             XMM Science Analysis Subsystem
 *
 *  Boolean task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolParameter.h,v 1.7 2000/10/25 12:33:31 jbakker Exp $
 *
 *****************************************************************************/

#ifndef BOOLPARAMETER_H
#define BOOLPARAMETER_H

#include "Parameter.h"           // headers
#include <string>


//================================================================
//  Class BoolParameter
//================================================================

class BoolParameter : public Parameter
{
public:
    // Construction
    BoolParameter* clone() { return new BoolParameter(*this); }

    // Value
    bool      boolValue() const { return _value; }
    bool      setNewValue(const string& value);
    bool      setValue(bool value);
    ParamType getType() const {return Parameter::Bool;}
    const char* getTypeName() const { return "bool"; }

    // Default
    bool      defaultValue() const {return _default;}
    bool      setNewDefault(const string& value);
    bool      setDefault(bool value);
    void      revertToDefault();

    // Formatting
    string    asString() const;
    string    defaultAsString() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.boolValue());}
    

    // Parsing
    bool parse(const string& str, bool& value);

    // Member data
    bool _value;
    bool _default;
};

#endif
