/*****************************************************************************
 *
 *  IntListParameter.h                          XMM Science Analysis Subsystem
 *
 *  Integer-list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntListParameter.h,v 1.9 2001/03/28 19:20:35 jbakker Exp $
 *
 *****************************************************************************/

#ifndef INTLISTPARAMETER_H
#define INTLISTPARAMETER_H

#include "Optional.h"            // SAS headers
#include "Parameter.h"

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class IntListParameter
//================================================================

class IntListParameter : public Parameter
{
public:
    // Construction
    IntListParameter* clone() { return new IntListParameter(*this); }

    // Value
    vector<int>          intListValue() const {return _value;}
    bool                 setNewValue(const string& value);
    bool                 setValue(const vector<int>& value);
    int                  size() const;
    ParamType            getType() const {return Parameter::IntList;}
    const char*          getTypeName() const { return "int_list"; }

    // Default
    vector<int>          defaultValue() const {return _default;}
    bool                 setNewDefault(const string& value);
    bool                 setDefault(const vector<int>& value);
    void                 revertToDefault();

    // Constraint
    void                 setMin(int minVal) {_min = minVal;}
    void                 setMax(int maxVal) {_max = maxVal;}
    const Optional<int>& minValue() const {return _min;}
    const Optional<int>& maxValue() const {return _max;}

    // Fomatting
    string               asString() const;
    string               defaultAsString() const;

    // Validation
    virtual bool         validate() const;    

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.intListValue());}

    // Parsing
    bool parse(const string& str, vector<int>& value);

    // Validation
    bool isValid(const vector<int>& n) const;
    void reportRangeError(const string& valueString);
    void writeConstraint(ostream& os) const;

    // Member data
    vector<int>   _value;
    vector<int>   _default;
    Optional<int> _min;
    Optional<int> _max;
};

#endif
