/*****************************************************************************
 *
 *  RealListParameter.h                         XMM Science Analysis Subsystem
 *
 *  Real list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealListParameter.h,v 1.11 2001/03/28 19:20:36 jbakker Exp $
 *
 *****************************************************************************/

#ifndef REALLISTPARAMETER_H
#define REALLISTPARAMETER_H

#include "Optional.h"            // SAS headers
#include "Parameter.h"

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class RealListParameter
//================================================================

class RealListParameter : public Parameter
{
public:
    // Construction
    RealListParameter* clone() { return new RealListParameter(*this); }

    // Value
    vector<double>     realListValue() const {return _value;}
    bool               setNewValue(const string& value);
    bool               setValue(const vector<double>& value);
    int                size() const;
    ParamType          getType() const {return Parameter::RealList;}
    const char*        getTypeName() const { return "real_list"; }

    // Default
    vector<double>     defaultValue() const {return _default;}
    bool               setNewDefault(const string& value);
    bool               setDefault(const vector<double>& value);
    void               revertToDefault();

    // Constraint
    void               setMin(double minVal) {_min = minVal;}
    void               setMax(double maxVal) {_max = maxVal;}
    const Optional<double>& minValue() const {return _min;}
    const Optional<double>& maxValue() const {return _max;}

    // Fomatting
    string             asString() const;
    string             defaultAsString() const;

    // Validation
    virtual bool       validate() const;

    // Parsing
    virtual bool       parse(const string& str, vector<double>& value);

protected:

    // Parsing
    virtual bool       parseDouble(const string& str, double& value, 
				   bool first=false);
    virtual string     doubleAsString(double value) const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.realListValue());}

    // Validation
    bool isValid(const vector<double>& n) const;
    void reportRangeError(const string& valueString);
    void writeConstraint(ostream& os) const;

    // Member data
    vector<double>   _value;
    vector<double>   _default;
    Optional<double> _min;
    Optional<double> _max;
};

#endif
