/*****************************************************************************
 *
 *  RealParameter.h                             XMM Science Analysis Subsystem
 *
 *  Real task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealParameter.h,v 1.12 2001/03/28 19:20:37 jbakker Exp $
 *
 *****************************************************************************/

#ifndef REALPARAMETER_H
#define REALPARAMETER_H

#include <iostream>             // C++ headers

#include "Optional.h"             // SAS headers
#include "Parameter.h"


//================================================================
//  Class RealParameter
//================================================================

class RealParameter : public Parameter
{
public:
    // Construction
    RealParameter* clone() { return new RealParameter(*this); }

    // Value
    double      realValue() const { return _value; }
    bool        setNewValue(const string& value);
    bool        setValue(double value);
    ParamType   getType() const {return Parameter::Real;}
    const char* getTypeName() const { return "real"; }

    // Default
    double     defaultValue() const {return _default;}
    bool       setNewDefault(const string& value);
    bool       setDefault(double value);
    void       revertToDefault();

    // Constraint
    void       setMin(double minVal) {_min = minVal;}
    void       setMax(double maxVal) {_max = maxVal;}
    const Optional<double>& minValue() const {return _min;}
    const Optional<double>& maxValue() const {return _max;}

    // Formatting
    string      asString() const;
    string     defaultAsString() const;

    // Validation
    bool        validate() const;

protected:
    // Parsing
    virtual bool parse(const string& str, double& value);

    // Member data
    double _value;
    double _default; 

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.realValue());}

    // Validation
    virtual bool isValid(double value) const;
    void reportRangeError(const string& valueString);
    void writeConstraint(ostream& os) const;

    // Member data
    Optional<double> _min;
    Optional<double> _max;
};

#endif
