/*****************************************************************************
 *
 *  param.h                                     XMM Science Analysis Subsystem
 *
 *  C task interface to parameter system
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: param.h,v 1.27 2000/06/23 09:20:45 jbakker Exp $
 *
 *****************************************************************************/

#ifndef __param_h
#define __param_h

#include <string>                  // C++ headers

#include "XpiInfoReader.h"         // Application headers
#include "Parameter.h"
#include <errstr.h>


// Global parameter information

extern ParameterInfo* gParameters;


//================================================================
//  Public interface
//================================================================

/*** Return the number of elements for a list parameter ***/

int parameterCount(const string& name);


/*** Return value of boolean parameter "name" ***/

bool booleanParameter(const string& name, int pos=-1);

// Work-around for egcs compiler problem with vector<bool>
vector<int> boolListParameter(const string& name);


/*** Return value of integer parameter "name" ***/

int intParameter(const string& name, int pos=-1);

vector<int> intListParameter(const string& name);


/*** Return value of real parameter "name" ***/

double realParameter(const string& name, int pos=-1);

vector<double> realListParameter(const string& name);


/*** Return value of string parameter "name" ***/

string stringParameter(const string& name, int pos=-1);

vector<string> stringListParameter(const string& name);


/*** Set the value of a parameter ***/

template<class T>
void setParameter(const string& name, const T& value)
{
    Parameter* p = (*gParameters)[name];
    if(p) {
      if(!p->setValue(value))
	errstr << "Value out of range for parameter '"
	       << name << "'" << Sas::error("ParamNotInRange");
    } else
      errstr << "Parameter " << name << " not found" 
	     << Sas::error("ParamNotFound");
}

template<class T>
void setParameter(const char* name, const T& value)
{
    setParameter(string(name), value);
}


//================================================================
//  Used only by taskmain
//================================================================

/*** Open the parameter set for task "name" ***/

void openParameters(const string& name);


/*** Close the parameter set ***/

void closeParameters();

#endif
