/****************************************************************************
 *
 *  testtimeangle.cc                           XMM Science Analysis Subsystem
 *
 *  Test time and angle parameters
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testtimeangle.cc,v 1.3 2001/03/28 19:20:41 jbakker Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>

#include <cmath>                    // C headers

#include <iostream>                // C++ headers
#include <string>

#include <errstr.h>

int main(int argc, char* argv[])
{
    const double epsilon = 1e-5;

    string taskname(argv[0]);
    errHandler.name(taskname);

    openParameters(taskname);
    gParameters->parseCommandLine(argc,argv);

    cout << endl << "Parameter info:" << endl 
	 << *gParameters << endl;


    /*** Time parameters ***/

    double time0 = -6901632.0;

    double time1  = realParameter("time1");
    cout << "time1   = " << time1 << endl;
    assert(fabs(time1 - time0) < fabs(time0) * epsilon);

    double time2  = realParameter("time2");
    cout << "time2   = " << time2 << endl;
    assert(fabs(time2 - time0) < fabs(time0) * epsilon);

    double time3  = realParameter("time3");
    cout << "time3   = " << time3 << endl;
    assert(fabs(time3 - time0) < fabs(time0) * epsilon);

    double time4  = realParameter("time4");
    cout << "time4   = " << time4 << endl;
    assert(fabs(time4 - time0) < fabs(time0) * epsilon);

    double time5  = realParameter("time5");
    cout << "time5   = " << time5 << endl;
    assert(fabs(time5 - time0) < fabs(time0) * epsilon);

    double time6  = realParameter("time6");
    cout << "time6   = " << time6 << endl;
    assert(fabs(time6 - time0) < fabs(time0) * epsilon);


    /*** Time-list parameters ***/

    int ntlist1 = parameterCount("tlist1");
    assert(ntlist1 == 3);
    for(int i=0; i<ntlist1; i++)
        cout << "tlist1[" << i << "] = " << realParameter("tlist1",i) << endl;
    double tref = -6901632.0;
    assert(fabs(realParameter("tlist1",0) - tref) < fabs(tref) * epsilon);
    assert(fabs(realParameter("tlist1",1) - tref) < fabs(tref) * epsilon);
    assert(fabs(realParameter("tlist1",2) - tref) < fabs(tref) * epsilon);

    int ntlist2 = parameterCount("tlist2");
    assert(ntlist2 == 2);
    for(int i=0; i<ntlist2; i++)
        cout << "tlist2[" << i << "] = " << realParameter("tlist2",i) << endl;
    //    double tref = -6.912e+06;
    assert(fabs(realParameter("tlist2",0) - tref) < fabs(tref) * epsilon);
    assert(fabs(realParameter("tlist2",1) - tref) < fabs(tref) * epsilon);


    /*** Angle parameters ***/

    double aref = 1.23456789;
    double angle1  = realParameter("angle1");
    cout << "angle1   = " << angle1 << endl;
    assert(fabs(angle1 - aref) < fabs(aref) * epsilon);

    aref = 188.7365833;
    double angle2  = realParameter("angle2");
    cout << "angle2   = " << angle2 << endl;
    assert(fabs(angle2 - aref) < fabs(aref) * epsilon);

    aref = -188.7365833;;
    double angle3  = realParameter("angle3");
    cout << "angle3   = " << angle3 << endl;
    assert(fabs(angle3 - aref) < fabs(aref) * epsilon);

    aref = -1.2345678;
    double angle4  = realParameter("angle4");
    cout << "angle4   = " << angle4 << endl;
    assert(fabs(angle4 - aref) < fabs(aref) * epsilon);


    /*** Angle-list parameters ***/

    int nalist1 = parameterCount("alist1");
    assert(nalist1 == 3);
    for(int i=0; i<nalist1; i++)
        cout << "alist1[" << i << "] = " << realParameter("alist1",i) << endl;
    double alref0 = 1.23456789;
    assert(fabs(realParameter("alist1",0) - alref0) < fabs(alref0) * epsilon);
    double alref1 = 188.7365833;
    assert(fabs(realParameter("alist1",1) - alref1) < fabs(alref1) * epsilon);
    double alref2 = -188.7365833;
    assert(fabs(realParameter("alist1",2) - alref2) < fabs(alref2) * epsilon);

    int nalist2 = parameterCount("alist2");
    assert(nalist2 == 2);
    for(int i=0; i<nalist2; i++)
        cout << "alist2[" << i << "] = " << realParameter("alist2",i) << endl;
    double alref3 = -1.23456789;
    assert(fabs(realParameter("alist2",0) - alref3) < fabs(alref3) * epsilon);
    double alref4 = 188.7365833;
    assert(fabs(realParameter("alist2",1) - alref4) < fabs(alref4) * epsilon);

    cout << gParameters->asCommandLine() << endl;

    closeParameters();

    return 0;
}
